/* *******************************************************************
   SD Card
   ***************************************************************** */

// Timer to log some data to SD Card
void timerSD()
{
  const uint32_t interval = 30 * 1000UL;
  static uint32_t previousMillis = 0;
  if (millis() - previousMillis > interval)
  {
    previousMillis = millis();
    if (timeStatus() != timeNotSet)
    {
      writeSD();
    }
    else
      Serial.println(F("Time not set - no log to SD"));
  }
}

void writeSD()      // Variant without buffer 29540 / 1378
{
  // make a string for assembling the data to log:
  const char * delimiter = {";"};        // delimiter between the fields

  File dataFile = SD.open(filename, FILE_WRITE);
  // if the file is available, write to it:
  if (dataFile) {
    dataFile.print(now());               // now() is a unsigned long, we need convert it to a string by base of 10
         
    // if you prefere a readable timestamp, use this
    dataFile.print(delimiter);  
    dataFile.print(year());
    dataFile.print("-");
    if (month() < 10) dataFile.print("0");
    dataFile.print(month());
    dataFile.print("-");
    if (day() < 10) dataFile.print("0");
    dataFile.print(day());
    dataFile.print(" ");
    if (hour() < 10) dataFile.print("0");
    dataFile.print(hour());
    dataFile.print(":");
    if (minute() < 10) dataFile.print("0");
    dataFile.print(minute());
    dataFile.print(":");
    if (second() < 10) dataFile.print("0");
    dataFile.print(second());

     // read the sensors and append to the string:
    for (auto & pin : analogPin) {
      dataFile.print(delimiter); 
      dataFile.print(analogRead(pin));
    }
    dataFile.println();
    dataFile.close();
    Serial.println(F("D58 Data was appended to the logfile"));
  }
  // if the file isn't open, pop up an error:
  else {
    Serial.println(F("error opening datalog.txt"));
  }
}

/*
void writeSDBuffer()      // Variant with an internal buffer 29798/1378
{
  // make a string for assembling the data to log:
  const char * delimiter = {";"};      // delimiter between the fields
  char buffer[60] {'\0'};              // you need a buffer large enough for your longest entry + \0
  char val[12] {'\0'};                 // for conversion of signed long numbers we need a separate buffer 11 characters (-2147483648) + \0.

  ultoa(now(), val, 10);               // now() is a unsigned long, we need convert it to a string by base of 10
  strcpy(buffer, val);                 // copy first value value to your buffer

  strcat(buffer, delimiter);           // if you prefere a readable timestamp, use this
  itoa(year(), val, 10);
  strcat(buffer, val);
  strcat(buffer, "-");
  itoa(month(), val, 10);
  if (month() < 10) strcat(buffer, "0");
  strcat(buffer, val);
  strcat(buffer, "-");
  itoa(day(), val, 10);
  if (day() < 10) strcat(buffer, "0");
  strcat(buffer, val);
  strcat(buffer, " ");
  itoa(hour(), val, 10);
  if (hour() < 10)strcat(buffer, "0");
  strcat(buffer, val);
  strcat(buffer, ":");
  itoa(minute(), val, 10);
  if (minute() < 10)strcat(buffer, "0");
  strcat(buffer, val);
  strcat(buffer, ":");
  itoa(second(), val, 10);
  if (second() < 10)strcat(buffer, "0");
  strcat(buffer, val);

  // read the sensors and append to the string:
  for (auto & pin : analogPin) {
    strcat(buffer, delimiter);
    int sensor = analogRead(pin);  // read the value
    itoa(sensor, val, 10);               // convert int to string by base of 10
    strcat(buffer, val);             // append value to your line
  }

  Serial.println(buffer);
  File dataFile = SD.open(filename, FILE_WRITE);
  // if the file is available, write to it:
  if (dataFile) {
    dataFile.println(buffer);
    dataFile.close();
    // print to the serial port too:
    //Serial.println(buffer);
  }
  // if the file isn't open, pop up an error:
  else {
    Serial.println(F("error opening datalog.txt"));
  }
}
*/
